@@ -30,3 +30,6 @@ class Healing(Step):
     def callback(self) -> bool:
         self.copilot.output_files(exclude_dirs=self.exclude_dirs)
         return True
+
+    def improvement_prompt(self) -> str:
+        return ""
