@@ -1,6 +1,9 @@
 from gpt_all_star.core.agents.copilot import Copilot
 from gpt_all_star.core.steps.step import Step
 from gpt_all_star.core.steps.system_design.additional_tasks import additional_tasks
+from gpt_all_star.core.steps.system_design.improvement_prompt import (
+    improvement_prompt_template,
+)
 
 
 class SystemDesign(Step):
@@ -22,3 +25,13 @@ class SystemDesign(Step):
         if has_technologies:
             self.copilot.output_md(technologies)
         return has_technologies
+
+    def improvement_prompt(self) -> str:
+        request = self.improvement_request or self.copilot.ask(
+            self._("What do you want to update?"), is_required=True, default=None
+        )
+        improvement_prompt = improvement_prompt_template.format(
+            request=request,
+            technologies=self.copilot.storages.docs.get("technologies.md", "N/A"),
+        )
+        return improvement_prompt
